@@ -1,4 +1,15 @@
-from nonebot.adapters.onebot.v11 import Bot
+from nonebot.adapters.onebot.v11 import Bot, MessageEvent
+
+
+# Rule
+async def msg_rule(bot: Bot, event: MessageEvent) -> bool:
+    if event.message_type == "group":
+        if event.group_id in get_mc_qq_group_list(bot):
+            return True
+    elif event.message_type == "guild":
+        for per_channel in get_mc_qq_guild_list(bot=bot):
+            if event.guild_id == per_channel[0] and event.channel_id == per_channel[1]:
+                return True
 
 
 # 发送消息到 QQ
@@ -26,14 +37,17 @@ async def send_msg_to_qq(bot, recv_msg):
 async def get_member_nickname(bot: Bot, event, user_id):
     # 判断从 群 或者 频道 获取成员信息
     if event.message_type == "group":
-        member_info = await bot.call_api(
-            "get_group_member_info",
-            group_id=event.group_id,
-            user_id=user_id,
-            no_cache=True
-        )
+        if event.sender.card == "":
+            return event.sender.nickname
+        else:
+            member_info = await bot.call_api(
+                "get_group_member_info",
+                group_id=event.group_id,
+                user_id=user_id,
+                no_cache=True
+            )
+            return member_info['card']
         # 返回群成员群名片
-        return member_info['card']
     else:
         member_info = await bot.call_api(
             "get_guild_member_profile",
@@ -46,13 +60,14 @@ async def get_member_nickname(bot: Bot, event, user_id):
 
 # 消息处理
 async def msg_process(bot: Bot, event):
+    # 获取昵称
+    member_nickname = await get_member_nickname(bot, event, event.user_id)
     # 命令信息起始
     command_msg = 'tellraw @a ["",'
     # 插件名与发言人昵称
     command_msg += '{"text":"[MC_QQ] ","color":"yellow"},{"text":"' + \
                    (
-                       # 获取昵称
-                       event.sender.card if event.message_type == "group" else event.sender.nickname
+                       member_nickname
                    ) + ' ","color":"aqua"},{"text":" 说：","color":"yellow"},'
     # 文本信息
     text_msg = ''
@@ -83,10 +98,10 @@ async def msg_process(bot: Bot, event):
             text_msg += '[视频] '
         # @
         elif msg.type == "at":
-            # 获取 群/频道 昵称
-            member_nickname = await get_member_nickname(bot, event, msg.data['qq'])
-            command_msg += '{"text": "@' + member_nickname + ' ","color": "green"},'
-            text_msg += '@' + member_nickname + ' '
+            # 获取被@ 群/频道 昵称
+            at_member_nickname = await get_member_nickname(bot, event, msg.data['qq'])
+            command_msg += '{"text": "@' + at_member_nickname + ' ","color": "green"},'
+            text_msg += '@' + at_member_nickname + ' '
         # share
         elif msg.type == "share":
             command_msg += '{"text": "[分享：' + msg.data[
